Crate typst_svg

Crate typst_svg 

Rendering of Typst documents into SVG images.

Structs

SvgOptions
Settings for SVG export.
WebImage
An image that is prepared for use in the web platform (SVG or HTML).

Functions

convert_image_scaling
Converts an image scaling to a CSS image-rendering property value.
svg
Export a frame into an SVG file.
svg_in_bundle
Export a page into an SVG file as part of a bundle.
svg_in_html
Export a frame into an SVG suitable for embedding into HTML.
svg_merged
Export a document with potentially multiple pages into a single SVG file.