Rendering of Typst documents into SVG images.
Structs
- SvgOptions
- Settings for SVG export.
- WebImage
- An image that is prepared for use in the web platform (SVG or HTML).
Functions
- convert_
image_ scaling - Converts an image scaling to a CSS
image-renderingproperty value. - svg
- Export a frame into an SVG file.
- svg_
in_ bundle - Export a page into an SVG file as part of a bundle.
- svg_
in_ html - Export a frame into an SVG suitable for embedding into HTML.
- svg_
merged - Export a document with potentially multiple pages into a single SVG file.